@@ -64,7 +64,6 @@ setGeneric('matchEnvData',
 
 #' @rdname matchEnvData
 #' @importFrom dplyr bind_rows bind_cols
-#' @importFrom hoardr hoard
 #' @export
 #'
 setMethod('matchEnvData', 'data.frame',
@@ -74,6 +73,9 @@ setMethod('matchEnvData', 'data.frame',
               if(is.null(nc)) {
                   nc <- browseEdinfo()
               }
+              if(!all(c('Latitude', 'Longitude') %in% standardCoordNames(colnames(data)))) {
+                  stop('Data must have columns "Latitude" and "Longitude"')
+              }
               if(is.character(nc) &&
                  !file.exists(nc)) {
                   nc <- try(erddapToEdinfo(nc, chooseVars = FALSE))
@@ -99,6 +101,10 @@ setMethod('matchEnvData', 'data.frame',
               if(!inherits(nc, 'edinfo')) {
                   stop(paste0('"nc" must be a valid nc file or erddap dataset id.'))
               }
+              if('UTC' %in% names(nc$limits) &&
+                 !'UTC' %in% standardCoordNames(colnames(data))) {
+                  stop('Data must have column "UTC"')
+              }
               if(is.null(nc$varSelect) ||
                  !any(nc$varSelect)) {
                   nc <- varSelect(nc, var)
@@ -159,7 +165,7 @@ setMethod('matchEnvData', 'data.frame',
                       planFiles[[p]] <- downloadEnv(data=data[plan == p, ],fileName = thisFile, edinfo = nc, buffer = buffer, ...)
                       #####################################
                       on.exit({
-                          tmpFiles <- list.files(hoard()$cache_path_set('PAMmisc'), full.names=TRUE)
+                          tmpFiles <- list.files(getTempCacheDir(), full.names=TRUE)
                           unlink(tmpFiles, force=TRUE)
                       })
                       # on.exit(DELETEYOUR PAMMISC TEMP DIR HERE) cache_delete_all from rerddap checkit
@@ -196,7 +202,7 @@ setMethod('matchEnvData', 'data.frame',
               # browser()
               if(length(ncData) > 1) {
                   message('Data crossed the dateline, download split into two files: ',
-                             ncData[1], ' and ', ncData[2])
+                          ncData[1], ' and ', ncData[2])
                   oldNames <- colnames(data)
                   colnames(data) <- standardCoordNames(colnames(data))
                   left <- to180(data$Longitude) > 0
